RtcCalibParam

Enum RtcCalibParam 

pub enum RtcCalibParam {
    Vlow,
    Vhigh,
    Vinit,
}
Available on crate feature unstable only.
Parameter selected from the ESP32-S2 RTC calibration table

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Vlow

Low-voltage ADC reading (calibration v1)



Vhigh

High-voltage ADC reading



Vinit

Initial code (calibration v2)