rtc_calib_reading

Function rtc_calib_reading 

pub fn rtc_calib_reading(
    version: u8,
    unit: u8,
    atten: Attenuation,
    param: RtcCalibParam,
) -> i32
Available on crate feature unstable only.
Reads a parsed RTC calibration table value.

See https://github.com/espressif/esp-idf/blob/027613140/components/efuse/esp32s2/esp_efuse_rtc_table.c#L145

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.